(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     17533,        445]
NotebookOptionsPosition[     14825,        396]
NotebookOutlinePosition[     15435,        419]
CellTagsIndexPosition[     15392,        416]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Chapter 5, Section 5.4, Figure 5.10a", "Section",ExpressionUUID->"925bc4b7-a6ca-48fd-b039-0574c422e5eb"],

Cell[TextData[{
 "We use the same functions, ",
 StyleBox["ksolve", "Input"],
 " and ",
 StyleBox["position", "Input"],
 ", as we used in ",
 StyleBox["Fig.5.9.nb",
  FontWeight->"Bold"],
 " to solve Kepler's equations and find the position vector as a function of \
mean anomaly."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"b890c465-fa6d-4860-80bc-bb8c268ea019"],

Cell["\<\
ksolve[ma_,e_]:=
 FindRoot[ea - e Sin[ea] == ma, {ea,ma}];\
\>", "Input",
 AspectRatioFixed->False,
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[1]:=",ExpressionUUID->"ea22817b-dbd3-4c1c-be9d-d343d22801fa"],

Cell["\<\
position[ma_,a_,e_]:=
(eca=ea/.ksolve[ma,e];
x=N[a(Cos[eca]-e)]; y=N[a Sqrt[1-e^2] Sin[eca]];
{x,y})\
\>", "Input",
 AspectRatioFixed->False,
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[2]:=",ExpressionUUID->"7edbcdaa-bc60-48c4-b1cb-d064192b4d2d"],

Cell[TextData[{
 "We will use a list, ",
 StyleBox["rotlist", "Input"],
 ", to store the points we calculate.  First we must set it to be empty."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"b154871b-aa1d-4ef3-9a69-76f6bb3cfc0a"],

Cell["rotlist={};", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[3]:=",ExpressionUUID->"c8b7a8fb-e0ae-4f7b-89c7-27f3cb0f937d"],

Cell[TextData[{
 "We are interested in the ",
 StyleBox["p", "Input"],
 " = 3/2 resonance with unit semi-major axis and an eccentricity, ",
 StyleBox["e", "Input"],
 " = 0.3."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"7650bf17-b4cc-4d80-8166-6271850e47a5"],

Cell["p=3/2; a=1.0; e=0.3;", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[4]:=",ExpressionUUID->"3faea373-3854-4591-95f6-4e81aef9bd23"],

Cell[TextData[{
 "Set up a loop to calculate and add points (positions at equal time \
intervals) to ",
 StyleBox["rotlist", "Input"],
 ".  Note that we have to go round the orbit twice."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"477852d6-8dfc-4f07-9e16-1496cad7ef1d"],

Cell["\<\
Do[
(posvec=position[t,a,e];
f=N[ArcTan[posvec[[1]],posvec[[2]]]];
rad=N[Sqrt[posvec[[1]]^2+posvec[[2]]^2]];
\[Theta]=p*t;
\[Psi]=\[Theta]-f;
blip=N[{rad*Cos[\[Psi]],rad*Sin[\[Psi]]}];
AppendTo[rotlist,blip];),
{t,0,4Pi,Pi/10}]\
\>", "Input",
 CellChangeTimes->{
  3.811322870680338*^9, {3.8113229051061707`*^9, 3.8113229058561296`*^9}},
 AspectRatioFixed->False,
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[5]:=",ExpressionUUID->"3a747fd9-9efd-4e14-ab53-3173e0cbbf51"],

Cell["Plot the resulting points.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"268368fa-0b70-4354-bbeb-c59773a5bc8a"],

Cell[CellGroupData[{

Cell["\<\
points=
ListPlot[rotlist,AspectRatio->Automatic,
PlotStyle->PointSize[0.02],Axes->None]\
\>", "Input",
 CellChangeTimes->{{3.811322721150605*^9, 3.811322740289936*^9}, {
  3.811322775634907*^9, 3.811322791438452*^9}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[6]:=",ExpressionUUID->"862ed031-fb2c-488d-9bb0-12cf70cb93e7"],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
    AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJw1klsow3EUx/9ZKGGNFikrhDwjtsyJ1JaSKB6US9MkD7zIbblmtdz2IrYo
Hrx48EJaSU5EU8zlSYh4mYhMiMhtO1+nfv0eTuec7/dzToqlrdIapihK1t8L
/k2h8JOCaMg+Lh1Jv6GPg9XwkhgPf0fqo6erbqlh46umOn+TC5uXMqOc9zRi
1my+q9Z4rKbO+Hb2SCt9b3nltmm60I96lJcARVQXFZ+++sjV0uV99ARIP9zd
/pRzRdrrjspE9wPZ9gYXIx23ZPfupFoMfpox7Sb03AUoLePownZ1QpoFDdV6
n8moyVG7nqYKfPvBeKEkyfN/vlfqeQ718dKf+9Ef89mI+dDHKugbF/2sg374
Yyv8/Yh/boR/i/Bh3aHwAT82fLQOxTqWC+qRL5I8gR93Sj0Z0D9Z+hP4sbk/
NJ8voe+mKqSP3dCfK/o5Af66xR+DH8+Kf64An2jhw1pnWYw1fnsd/NgAvmrk
beA/j3o19jOE/pPYXwXmQx/FCT+ewP7tA6KfcB/nJvH3ifvZgH8r7uvZJ3z+
70/4ba3/AtGQU/c=
     "]]}, {{}, {}}},
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-1.0595709962541302`, 1.0595709962541302`}, {-1.3, 1.3}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.811322702538196*^9, 3.811322741460024*^9}, {
   3.811322780448944*^9, 3.811322792025545*^9}, {3.81132287537928*^9, 
   3.8113229215623407`*^9}, 3.811323006796144*^9},
 CellLabel->"Out[6]=",ExpressionUUID->"3c3b1707-7f9d-4c65-a2ed-384213a55320"]
}, Open  ]],

Cell[TextData[{
 "Now go through the same procedure again but with more points in order to \
plot the path in the rotating frame.  First set the contents of ",
 StyleBox["rotlist", "Input"],
 " to be empty."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"95243fd2-9abf-459a-9ac5-05b0c6968733"],

Cell["rotlist = {};", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[7]:=",ExpressionUUID->"c1db4d3e-8fec-40ed-b990-dad8af06b612"],

Cell["Create the points in a loop ...", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"31da03a3-2002-4ae3-9945-1bf2fd3b76d4"],

Cell["\<\
Do[
(posvec=position[t,a,e];
f=N[ArcTan[posvec[[1]],posvec[[2]]]];
rad=N[Sqrt[posvec[[1]]^2+posvec[[2]]^2]];
\[Theta]=p*t;
\[Psi]=\[Theta]-f;
blip=N[{rad*Cos[\[Psi]],rad*Sin[\[Psi]]}];
AppendTo[rotlist,blip];),
{t,0,4Pi,Pi/40}]\
\>", "Input",
 AspectRatioFixed->False,
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[8]:=",ExpressionUUID->"278f5ddb-7078-43a1-b8a7-7dbb72888174"],

Cell["... and plot them.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"159fc629-d2ad-41f8-8ee6-0c09e8852a54"],

Cell[CellGroupData[{

Cell["\<\
curve =
ListPlot[rotlist,PlotJoined->True,
 AspectRatio->Automatic, Axes->None]\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[9]:=",ExpressionUUID->"03f125f6-164d-4163-b087-fa931fee02f4"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668], 
     AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxVlnlQ1HUYxncEjxyEWRCRLSlNkGhMTYrbV9BgVTRkBiksBRTkyAslORTT
ETMEERREceSYbBQ1FVOUGF7vZUJUQEOhJS9udHdjG83GLPd9thl/Mzv7x3e+
x/u+z/N537HRK0NjBikUirL/fq/+Y01fJynwOaZOGRme1EmlLq4jJw/ey7rD
9S8nFnaSbWFB0ukDh3jlZUWivrGTOpqLFFHPTnLk1MbZWc5d9Pz66cEzR1Sx
T3JUY8XOLtL5+S/bFP0z+671n1hi201Tgqa1VN+sZbcJ5as/rOimiWWVxrR9
5/mfoV5We8J6KLL2RcQCzwu8IMc1bqFtL4WkDDZ2uF/gRdd0/vHaXnrxXkPe
55nnWXPpoqX1qT5qGnK2MiCglqfFHZswPLefstTKC88sqvnN2RnFB796THXq
uDKV+icO/KDniCbwCb3je/0TjUMFp5xxUypH68j913XldYF5nB2xyO9pq45O
ZTz1+DR9D21oT7DXz9QTvdSEV6ScpI/VLlYluXoKLrXUJsbX0kjr7C9u/6In
hSo+9mTwVdJ6ba9SGPU0ZIF/wN0/GyjAYphDzTAD3b3haPmDTTMFz6kIbxti
INt5A2X6iBaqdpvRmNyvpztVmZsmN7VRUUKKRlelJ68tqWsN7veoYYz1zkFx
evJZ8+SNB1kPKOR4U+nWpzr6LiN24/pHj2hnW8HqkI4ntDq3LcjJp4vs738d
OnrvY0qv33R46LYeijrmsTTKrp/K0kLWr73cR4kd4Y3rw3ppqzYj4nTPY8o/
qn/r26huakpzbVYbdJSpuTIu2ruTioPqHNJ69TSmZM39Iw8fkras5cflGgO9
iNG6V0bdp84VkfX12X+Q49b4ZZokLWUXTprk4jlA77rc1KbfayHl90r6UjNA
BS1p55JGN1F86ZKwQ55Gysk/YdUwr47aW4df2Z9lJOddtX3HE85Sy4Dfiqk1
RvJTutsUGQp9G669+oxkKetsXg+V/fw79ufI+ZyI81VyP5vvHy/v4+14n0Ws
6f3cgfePlfi4DfFtkPi5BPFvkfxwK/ITL/nj7chfnOSX9yG/dpJ/3oj850l9
2FyfIKkf70L9bkh92QP1Rf3ZD/U/K/rgTuhjluiH3aGf6aIv7oa+oD+2gP5G
iT652lH06SH6ZVfoN0P0zW7Qd47on52gf/iD598Wf6jFP3wQ/lGJvzgf/oL/
OAb+uyr+5APwJ/zL9m7i33DxNy+Hv1+K/3kJ/P++8IHNfAA/WAl++Apf2Ai+
RAt/2OmG8Ad84nPgk174xeMKhF/gG89zFr6Bf+z9fMVm622Vvub19PGmdTJg
/5ndpv1kPr9dzqfFuN9f7ifwj1XTTO8jH7zfS95ProhvhMRH4B+vk/gpDPnZ
LPmhxcifUfhHV5DfhZJf8kb+x0j+yVwfz1mm+lAQ6jdK6vd/fd8W/hH4x+qN
pvpzOvSRLPpgT+hnoMSkH7aDvsYL/7gd+usKM+mPwT9uFX3yHOjXWfTLl6Dv
ItE374X+PxL9cz38MV38wbPhn2zxD++GvxLFX+wA/6WK/zgU/jwh/uRV8C/4
x8Xwd534m8E/3i/+Zx/w4bbwgbuEf9wv/GAr8AX84/ngj5Xwh5Nf5xOrdgm/
fhN+cXn+a3xj+9y5I2LsLteAf+wt63QH613gpxb7t4CvCTjfG/y1wf0q8Bn8
4zbwW4f3TwHf7yK+dPC/FPGXoz9cRX5i0T92IH9z0F+qkV8b9J/NyP8O9Kdk
1GcG+tce1O/66/2Nd6P/zUf9Gf2xAvoIQv/0gH4C0V+PQl/QH9kK/9gW/Xku
9OmN/n0R+jX395nQ9w70/8xvRP+pmA/6bok/gjE/5HmLf5wwXwwI/4gwf7QF
if/M88lf8Gck5pcU4R99hvlmKfz9N+afWvjfPB+NAx/8MD8VBwo//DBfPRD+
UQzmr4EG4c8qzGeLbgmfwC9Sg18qzHfNE4Rv5vlP+Hex5l+ZLVM4
      "]]}}, {{}, {}}},
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-1.0646325015697617`, 1.0646325015697626`}, {-1.3, 1.3}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.8113227029997168`*^9, 3.811322975467801*^9, 
  3.811323007275023*^9},
 CellLabel->"Out[9]=",ExpressionUUID->"4edea092-041f-425c-88a5-d3aed4bedfa5"]
}, Open  ]],

Cell["Finally, display the points and the curve on the same plot.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"1803568a-973d-4c6c-ac1d-21bc9e7ac7e3"],

Cell[CellGroupData[{

Cell["Show[points,curve]", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[10]:=",ExpressionUUID->"6437ec66-0673-46fc-b23b-3bae1f4c8b7b"],

Cell[BoxData[
 GraphicsBox[{{{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.02], 
     AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJw1klsow3EUx/9ZKGGNFikrhDwjtsyJ1JaSKB6US9MkD7zIbblmtdz2IrYo
Hrx48EJaSU5EU8zlSYh4mYhMiMhtO1+nfv0eTuec7/dzToqlrdIapihK1t8L
/k2h8JOCaMg+Lh1Jv6GPg9XwkhgPf0fqo6erbqlh46umOn+TC5uXMqOc9zRi
1my+q9Z4rKbO+Hb2SCt9b3nltmm60I96lJcARVQXFZ+++sjV0uV99ARIP9zd
/pRzRdrrjspE9wPZ9gYXIx23ZPfupFoMfpox7Sb03AUoLePownZ1QpoFDdV6
n8moyVG7nqYKfPvBeKEkyfN/vlfqeQ718dKf+9Ef89mI+dDHKugbF/2sg374
Yyv8/Yh/boR/i/Bh3aHwAT82fLQOxTqWC+qRL5I8gR93Sj0Z0D9Z+hP4sbk/
NJ8voe+mKqSP3dCfK/o5Af66xR+DH8+Kf64An2jhw1pnWYw1fnsd/NgAvmrk
beA/j3o19jOE/pPYXwXmQx/FCT+ewP7tA6KfcB/nJvH3ifvZgH8r7uvZJ3z+
70/4ba3/AtGQU/c=
      "]]}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxVlnlQ1HUYxncEjxyEWRCRLSlNkGhMTYrbV9BgVTRkBiksBRTkyAslORTT
ETMEERREceSYbBQ1FVOUGF7vZUJUQEOhJS9udHdjG83GLPd9thl/Mzv7x3e+
x/u+z/N537HRK0NjBikUirL/fq/+Y01fJynwOaZOGRme1EmlLq4jJw/ey7rD
9S8nFnaSbWFB0ukDh3jlZUWivrGTOpqLFFHPTnLk1MbZWc5d9Pz66cEzR1Sx
T3JUY8XOLtL5+S/bFP0z+671n1hi201Tgqa1VN+sZbcJ5as/rOimiWWVxrR9
5/mfoV5We8J6KLL2RcQCzwu8IMc1bqFtL4WkDDZ2uF/gRdd0/vHaXnrxXkPe
55nnWXPpoqX1qT5qGnK2MiCglqfFHZswPLefstTKC88sqvnN2RnFB796THXq
uDKV+icO/KDniCbwCb3je/0TjUMFp5xxUypH68j913XldYF5nB2xyO9pq45O
ZTz1+DR9D21oT7DXz9QTvdSEV6ScpI/VLlYluXoKLrXUJsbX0kjr7C9u/6In
hSo+9mTwVdJ6ba9SGPU0ZIF/wN0/GyjAYphDzTAD3b3haPmDTTMFz6kIbxti
INt5A2X6iBaqdpvRmNyvpztVmZsmN7VRUUKKRlelJ68tqWsN7veoYYz1zkFx
evJZ8+SNB1kPKOR4U+nWpzr6LiN24/pHj2hnW8HqkI4ntDq3LcjJp4vs738d
OnrvY0qv33R46LYeijrmsTTKrp/K0kLWr73cR4kd4Y3rw3ppqzYj4nTPY8o/
qn/r26huakpzbVYbdJSpuTIu2ruTioPqHNJ69TSmZM39Iw8fkras5cflGgO9
iNG6V0bdp84VkfX12X+Q49b4ZZokLWUXTprk4jlA77rc1KbfayHl90r6UjNA
BS1p55JGN1F86ZKwQ55Gysk/YdUwr47aW4df2Z9lJOddtX3HE85Sy4Dfiqk1
RvJTutsUGQp9G669+oxkKetsXg+V/fw79ufI+ZyI81VyP5vvHy/v4+14n0Ws
6f3cgfePlfi4DfFtkPi5BPFvkfxwK/ITL/nj7chfnOSX9yG/dpJ/3oj850l9
2FyfIKkf70L9bkh92QP1Rf3ZD/U/K/rgTuhjluiH3aGf6aIv7oa+oD+2gP5G
iT652lH06SH6ZVfoN0P0zW7Qd47on52gf/iD598Wf6jFP3wQ/lGJvzgf/oL/
OAb+uyr+5APwJ/zL9m7i33DxNy+Hv1+K/3kJ/P++8IHNfAA/WAl++Apf2Ai+
RAt/2OmG8Ad84nPgk174xeMKhF/gG89zFr6Bf+z9fMVm622Vvub19PGmdTJg
/5ndpv1kPr9dzqfFuN9f7ifwj1XTTO8jH7zfS95ProhvhMRH4B+vk/gpDPnZ
LPmhxcifUfhHV5DfhZJf8kb+x0j+yVwfz1mm+lAQ6jdK6vd/fd8W/hH4x+qN
pvpzOvSRLPpgT+hnoMSkH7aDvsYL/7gd+usKM+mPwT9uFX3yHOjXWfTLl6Dv
ItE374X+PxL9cz38MV38wbPhn2zxD++GvxLFX+wA/6WK/zgU/jwh/uRV8C/4
x8Xwd534m8E/3i/+Zx/w4bbwgbuEf9wv/GAr8AX84/ngj5Xwh5Nf5xOrdgm/
fhN+cXn+a3xj+9y5I2LsLteAf+wt63QH613gpxb7t4CvCTjfG/y1wf0q8Bn8
4zbwW4f3TwHf7yK+dPC/FPGXoz9cRX5i0T92IH9z0F+qkV8b9J/NyP8O9Kdk
1GcG+tce1O/66/2Nd6P/zUf9Gf2xAvoIQv/0gH4C0V+PQl/QH9kK/9gW/Xku
9OmN/n0R+jX395nQ9w70/8xvRP+pmA/6bok/gjE/5HmLf5wwXwwI/4gwf7QF
if/M88lf8Gck5pcU4R99hvlmKfz9N+afWvjfPB+NAx/8MD8VBwo//DBfPRD+
UQzmr4EG4c8qzGeLbgmfwC9Sg18qzHfNE4Rv5vlP+Hex5l+ZLVM4
       "]]}}, {{}, {}}}},
  
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-1.0595709962541302`, 1.0595709962541302`}, {-1.3, 1.3}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.81132270350511*^9, 3.811322801054438*^9, {3.8113229793883057`*^9, 
   3.8113230072803307`*^9}},
 CellLabel->"Out[10]=",ExpressionUUID->"deeaeb39-d9d9-438f-ad6b-f41027d5b981"]
}, Open  ]]
},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{919, 626},
WindowMargins->{{17, Automatic}, {Automatic, 322}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowCellLabel->True,
ShowCellTags->False,
FrontEndVersion->"12.1 for Mac OS X x86 (64-bit) (June 19, 2020)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"7ae0b48e-458a-42b4-96cd-eaf5c56de7e6"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 110, 0, 67, "Section",ExpressionUUID->"925bc4b7-a6ca-48fd-b039-0574c422e5eb"],
Cell[671, 22, 403, 13, 72, "Text",ExpressionUUID->"b890c465-fa6d-4860-80bc-bb8c268ea019"],
Cell[1077, 37, 219, 6, 48, "Input",ExpressionUUID->"ea22817b-dbd3-4c1c-be9d-d343d22801fa"],
Cell[1299, 45, 261, 8, 84, "Input",ExpressionUUID->"7edbcdaa-bc60-48c4-b1cb-d064192b4d2d"],
Cell[1563, 55, 267, 7, 53, "Text",ExpressionUUID->"b154871b-aa1d-4ef3-9a69-76f6bb3cfc0a"],
Cell[1833, 64, 138, 2, 30, "Input",ExpressionUUID->"c8b7a8fb-e0ae-4f7b-89c7-27f3cb0f937d"],
Cell[1974, 68, 297, 9, 53, "Text",ExpressionUUID->"7650bf17-b4cc-4d80-8166-6271850e47a5"],
Cell[2274, 79, 147, 2, 30, "Input",ExpressionUUID->"3faea373-3854-4591-95f6-4e81aef9bd23"],
Cell[2424, 83, 309, 8, 76, "Text",ExpressionUUID->"477852d6-8dfc-4f07-9e16-1496cad7ef1d"],
Cell[2736, 93, 483, 15, 174, "Input",ExpressionUUID->"3a747fd9-9efd-4e14-ab53-3173e0cbbf51"],
Cell[3222, 110, 152, 3, 53, "Text",ExpressionUUID->"268368fa-0b70-4354-bbeb-c59773a5bc8a"],
Cell[CellGroupData[{
Cell[3399, 117, 337, 8, 66, "Input",ExpressionUUID->"862ed031-fb2c-488d-9bb0-12cf70cb93e7"],
Cell[3739, 127, 1926, 47, 449, "Output",ExpressionUUID->"3c3b1707-7f9d-4c65-a2ed-384213a55320"]
}, Open  ]],
Cell[5680, 177, 329, 8, 76, "Text",ExpressionUUID->"95243fd2-9abf-459a-9ac5-05b0c6968733"],
Cell[6012, 187, 140, 2, 30, "Input",ExpressionUUID->"c1db4d3e-8fec-40ed-b990-dad8af06b612"],
Cell[6155, 191, 157, 3, 53, "Text",ExpressionUUID->"31da03a3-2002-4ae3-9945-1bf2fd3b76d4"],
Cell[6315, 196, 388, 13, 174, "Input",ExpressionUUID->"278f5ddb-7078-43a1-b8a7-7dbb72888174"],
Cell[6706, 211, 144, 3, 53, "Text",ExpressionUUID->"159fc629-d2ad-41f8-8ee6-0c09e8852a54"],
Cell[CellGroupData[{
Cell[6875, 218, 214, 6, 66, "Input",ExpressionUUID->"03f125f6-164d-4163-b087-fa931fee02f4"],
Cell[7092, 226, 3295, 69, 449, "Output",ExpressionUUID->"4edea092-041f-425c-88a5-d3aed4bedfa5"]
}, Open  ]],
Cell[10402, 298, 185, 3, 53, "Text",ExpressionUUID->"1803568a-973d-4c6c-ac1d-21bc9e7ac7e3"],
Cell[CellGroupData[{
Cell[10612, 305, 146, 2, 30, "Input",ExpressionUUID->"6437ec66-0673-46fc-b23b-3bae1f4c8b7b"],
Cell[10761, 309, 4048, 84, 472, "Output",ExpressionUUID->"deeaeb39-d9d9-438f-ad6b-f41027d5b981"]
}, Open  ]]
}
]
*)

